==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridFilterDialogViewModelRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelRowDescription } from "./GridFilterDialogViewModelRowDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelRowDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelRowDescriptionMetadata.a == null) {
                GridFilterDialogViewModelRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelRowDescriptionMetadata.c(GridFilterDialogViewModelRowDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogViewModelRowDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridFilterDialogViewModelRowDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Operators", "Array:string");
            a.item("CurrentOperator", "String");
            a.item("OperandNumber", "Array:int");
            a.item("Operand1Ref", "(w:Operand1,wf:Operand1)DataRef");
            a.item("Operand2Ref", "(w:Operand2,wf:Operand2)DataRef");
        }
        static d(a) {
            GridFilterDialogViewModelRowDescriptionMetadata.b(a);
            a.ad("GridFilterDialogViewModelRow", () => new GridFilterDialogViewModelRowDescription());
            a.ac("GridFilterDialogViewModelRow", GridFilterDialogViewModelRowDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelRowDescriptionMetadata.$t = markType(GridFilterDialogViewModelRowDescriptionMetadata, 'GridFilterDialogViewModelRowDescriptionMetadata');
    GridFilterDialogViewModelRowDescriptionMetadata.a = null;
    return GridFilterDialogViewModelRowDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridFilterDialogViewModelRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelRowDescription } from "./GridFilterDialogViewModelRowDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelRowDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelRowDescriptionMetadata.a == null) {
                GridFilterDialogViewModelRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelRowDescriptionMetadata.c(GridFilterDialogViewModelRowDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogViewModelRowDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridFilterDialogViewModelRowDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Operators", "Array:string");
            a.item("CurrentOperator", "String");
            a.item("OperandNumber", "Array:int");
            a.item("Operand1Ref", "(w:Operand1,wf:Operand1)DataRef");
            a.item("Operand2Ref", "(w:Operand2,wf:Operand2)DataRef");
        }
        static d(a) {
            GridFilterDialogViewModelRowDescriptionMetadata.b(a);
            a.ae("GridFilterDialogViewModelRow", () => new GridFilterDialogViewModelRowDescription());
            a.ad("GridFilterDialogViewModelRow", GridFilterDialogViewModelRowDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelRowDescriptionMetadata.$t = markType(GridFilterDialogViewModelRowDescriptionMetadata, 'GridFilterDialogViewModelRowDescriptionMetadata');
    GridFilterDialogViewModelRowDescriptionMetadata.a = null;
    return GridFilterDialogViewModelRowDescriptionMetadata;
})();
